pub struct StateMachine<M>where
M: IntoStateMachine,{ /* private fields */ }Expand description
A state machine that will be lazily initialized.
Implementations
Sourceimpl<M> StateMachine<M>
impl<M> StateMachine<M>
Sourcepub fn init(&mut self)where
for<'ctx> M: IntoStateMachine<Context<'ctx> = ()>,
pub fn init(&mut self)where
for<'ctx> M: IntoStateMachine<Context<'ctx> = ()>,
Explicitly initialize the state machine. If the state machine is already initialized this is a no-op.
Sourcepub fn init_with_context(&mut self, context: &mut M::Context<'_>)
pub fn init_with_context(&mut self, context: &mut M::Context<'_>)
Explicitly initialize the state machine. If the state machine is already initialized this is a no-op.
Sourcepub fn handle(&mut self, event: &M::Event<'_>)where
for<'ctx> M: IntoStateMachine<Context<'ctx> = ()>,
pub fn handle(&mut self, event: &M::Event<'_>)where
for<'ctx> M: IntoStateMachine<Context<'ctx> = ()>,
Handle an event. If the state machine is still uninitialized, it will be initialized before handling the event.
Sourcepub fn handle_with_context(
&mut self,
event: &M::Event<'_>,
context: &mut M::Context<'_>,
)
pub fn handle_with_context( &mut self, event: &M::Event<'_>, context: &mut M::Context<'_>, )
Handle an event. If the state machine is still uninitialized, it will be initialized before handling the event.
pub fn step(&mut self)
pub fn step_with_context(&mut self, context: &mut M::Context<'_>)where
for<'evt> M: IntoStateMachine<Event<'evt> = ()>,
Sourcepub fn inner(&self) -> &M
pub fn inner(&self) -> &M
Get a reference to the StateMachine’s underlying type.
let state_machine = Blinky::default().state_machine();
assert_eq!(state_machine.inner().led, false);Sourcepub unsafe fn inner_mut(&mut self) -> &mut M
pub unsafe fn inner_mut(&mut self) -> &mut M
Get a mutable reference to the StateMachine’s underlying type.
Safety
- The user is responsible for validating that mutating a StateMachine does not break any invariants.
let mut state_machine = Blinky::default().state_machine();
unsafe {
state_machine.inner_mut().led = true;
}Sourcepub unsafe fn state_mut(&mut self) -> &mut M::State
pub unsafe fn state_mut(&mut self) -> &mut M::State
Get a mutable reference to the StateMachine’s current state.
Safety
- The user is responsible for validating that mutating a StateMachine does not break any invariants.
let mut state_machine = Blinky::default().state_machine();
unsafe {
*state_machine.state_mut() = State::on();
}Trait Implementations
Sourceimpl<M> Clone for StateMachine<M>
impl<M> Clone for StateMachine<M>
Sourceimpl<M> Component for StateMachine<M>
Available on crate feature bevy only.
impl<M> Component for StateMachine<M>
bevy only.Sourcetype Storage = TableStorage
type Storage = TableStorage
TableStorage or SparseStorage.Sourceimpl<M> Default for StateMachine<M>where
M: IntoStateMachine + Default,
impl<M> Default for StateMachine<M>where
M: IntoStateMachine + Default,
Sourceimpl<M> Deref for StateMachine<M>where
M: IntoStateMachine,
impl<M> Deref for StateMachine<M>where
M: IntoStateMachine,
Sourceimpl<'de, M> Deserialize<'de> for StateMachine<M>
Available on crate feature serde only.A serialized state machine can only be deserialized into an UninitializedStateMachine and can
then be initialized with init.
impl<'de, M> Deserialize<'de> for StateMachine<M>
serde only.A serialized state machine can only be deserialized into an UninitializedStateMachine and can
then be initialized with init.
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<M> From<InitializedStateMachine<M>> for StateMachine<M>where
M: IntoStateMachine,
impl<M> From<InitializedStateMachine<M>> for StateMachine<M>where
M: IntoStateMachine,
Sourcefn from(value: InitializedStateMachine<M>) -> Self
fn from(value: InitializedStateMachine<M>) -> Self
Sourceimpl<M> From<UninitializedStateMachine<M>> for StateMachine<M>where
M: IntoStateMachine,
impl<M> From<UninitializedStateMachine<M>> for StateMachine<M>where
M: IntoStateMachine,
Sourcefn from(value: UninitializedStateMachine<M>) -> Self
fn from(value: UninitializedStateMachine<M>) -> Self
Sourceimpl<M> PartialEq for StateMachine<M>
impl<M> PartialEq for StateMachine<M>
Sourceimpl<M> Serialize for StateMachine<M>
Available on crate feature serde only.
impl<M> Serialize for StateMachine<M>
serde only.impl<M> Eq for StateMachine<M>